@@ -13,6 +13,17 @@ TpProxySignalConnection *tp_cli_connection_connect_to_self_handle_changed (TpCon
     GObject *weak_object,
     GError **error);
 
+typedef void (*tp_cli_connection_signal_callback_self_contact_changed) (TpConnection *proxy,
+    guint arg_Self_Handle,
+    const gchar *arg_Self_ID,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_connect_to_self_contact_changed (TpConnection *proxy,
+    tp_cli_connection_signal_callback_self_contact_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
 typedef void (*tp_cli_connection_signal_callback_new_channel) (TpConnection *proxy,
     const gchar *arg_Object_Path,
     const gchar *arg_Channel_Type,
