@@ -229,6 +229,9 @@ tp_svc_connection_return_from_remove_client_interest (DBusGMethodInvocation *con
 
 void tp_svc_connection_emit_self_handle_changed (gpointer instance,
     guint arg_Self_Handle);
+void tp_svc_connection_emit_self_contact_changed (gpointer instance,
+    guint arg_Self_Handle,
+    const gchar *arg_Self_ID);
 void tp_svc_connection_emit_new_channel (gpointer instance,
     const gchar *arg_Object_Path,
     const gchar *arg_Channel_Type,
